@@ -34,17 +34,16 @@
 #include "callbacks.h"
 #include "interface.h"
 #include "proctable.h"
-#include "infoview.h"
 #include "procactions.h"
 #include "load-graph.h"
 #include "util.h"
+#include "disks.h"
 
 static void	cb_toggle_tree (GtkAction *action, gpointer data);
-static void	cb_toggle_threads (GtkAction *action, gpointer data);
 
 static const GtkActionEntry menu_entries[] =
 {
-	{ "File", NULL, N_("_File") },
+	{ "Monitor", NULL, N_("_Monitor") },
 	{ "Edit", NULL, N_("_Edit") },
 	{ "View", NULL, N_("_View") },
 	{ "Help", NULL, N_("_Help") },
@@ -52,6 +51,12 @@ static const GtkActionEntry menu_entries[] =
 	{ "Quit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q",
 	  N_("Quit the program"), G_CALLBACK (cb_app_exit) },
 
+
+	{ "StopProcess", NULL, N_("_Stop Process"), "<control>S",
+	  N_("Stop process"), G_CALLBACK(cb_kill_sigstop) },
+	{ "ContProcess", NULL, N_("_Continue Process"), "<control>C",
+	  N_("Continue process if stopped"), G_CALLBACK(cb_kill_sigcont) },
+
 	{ "EndProcess", NULL, N_("End _Process"), "<control>E",
 	  N_("Force process to finish normally"), G_CALLBACK (cb_end_process) },
 	{ "KillProcess", NULL, N_("_Kill Process"), "<control>K",
@@ -81,17 +86,29 @@ static const GtkToggleActionEntry toggle_menu_entries[] =
 	{ "ShowDependencies", NULL, N_("_Dependencies"), "<control>D",
 	  N_("Show parent/child relationship between processes"),
 	  G_CALLBACK (cb_toggle_tree), TRUE },
-	{ "ShowThreads", NULL, N_("_Threads"), "<control>T",
-	  N_("Show each thread as a separate process"),
-	  G_CALLBACK (cb_toggle_threads), FALSE }
 };
 
+
+static const GtkRadioActionEntry radio_menu_entries[] =
+{
+  { "ShowActiveProcesses", NULL, N_("_Active Processes"), NULL,
+    N_("Show active processes"), ACTIVE_PROCESSES },
+  { "ShowAllProcesses", NULL, N_("A_ll Processes"), NULL,
+    N_("Show all processes"), ALL_PROCESSES },
+  { "ShowMyProcesses", NULL, N_("M_y Processes"), NULL,
+    N_("Show user own process"), MY_PROCESSES }
+};
+
+
 static const char ui_info[] =
 "  <menubar name=\"MenuBar\">"
-"    <menu name=\"FileMenu\" action=\"File\">"
-"      <menuitem name=\"FileQuitMenu\" action=\"Quit\" />"
+"    <menu name=\"MonitorMenu\" action=\"Monitor\">"
+"      <menuitem name=\"MonitorQuitMenu\" action=\"Quit\" />"
 "    </menu>"
 "    <menu name=\"EditMenu\" action=\"Edit\">"
+"      <menuitem name=\"EditStopProcessMenu\" action=\"StopProcess\" />"
+"      <menuitem name=\"EditContProcessMenu\" action=\"ContProcess\" />"
+"      <separator />"
 "      <menuitem name=\"EditEndProcessMenu\" action=\"EndProcess\" />"
 "      <menuitem name=\"EditKillProcessMenu\" action=\"KillProcess\" />"
 "      <separator />"
@@ -100,8 +117,11 @@ static const char ui_info[] =
 "      <menuitem name=\"EditPreferenciesMenu\" action=\"Preferencies\" />"
 "    </menu>"
 "    <menu name=\"ViewMenu\" action=\"View\">"
+"      <menuitem name=\"ViewActiveProcesses\" action=\"ShowActiveProcesses\" />"
+"      <menuitem name=\"ViewAllProcesses\" action=\"ShowAllProcesses\" />"
+"      <menuitem name=\"ViewMyProcesses\" action=\"ShowMyProcesses\" />"
+"      <separator />"
 "      <menuitem name=\"ViewDependenciesMenu\" action=\"ShowDependencies\" />"
-"      <menuitem name=\"ViewThreadsMenu\" action=\"ShowThreads\" />"
 "      <separator />"
 "      <menuitem name=\"ViewHideProcessMenu\" action=\"HideProcess\" />"
 "      <menuitem name=\"ViewHiddenProcessesMenu\" action=\"HiddenProcesses\" />"
@@ -115,6 +135,9 @@ static const char ui_info[] =
 "    </menu>"
 "  </menubar>"
 "  <popup name=\"PopupMenu\" action=\"Popup\">"
+"    <menuitem action=\"StopProcess\" />"
+"    <menuitem action=\"ContProcess\" />"
+"    <separator />"
 "    <menuitem action=\"EndProcess\" />"
 "    <menuitem action=\"KillProcess\" />"
 "    <separator />"
@@ -130,11 +153,9 @@ static const char ui_info[] =
 static GtkWidget *
 create_proc_view (ProcData *procdata)
 {
-	GtkWidget *vbox1, *vbox2;
+	GtkWidget *vbox1;
 	GtkWidget *hbox1;
-	GtkWidget *proc_combo;
 	GtkWidget *scrolled;
-	GtkWidget *label;
 	GtkWidget *hbox2;
 	char* string;
 
@@ -149,22 +170,6 @@ create_proc_view (ProcData *procdata)
 	g_free (string);
 	gtk_box_pack_start (GTK_BOX (hbox1), procdata->loadavg, FALSE, FALSE, 0);
 
-	proc_combo = gtk_combo_box_new_text ();
-	gtk_box_pack_end (GTK_BOX (hbox1), proc_combo, FALSE, FALSE, 0);
-
-	gtk_combo_box_insert_text (GTK_COMBO_BOX (proc_combo), ALL_PROCESSES, _("All processes"));
-	gtk_combo_box_insert_text (GTK_COMBO_BOX (proc_combo), MY_PROCESSES, _("My processes"));
-	gtk_combo_box_insert_text (GTK_COMBO_BOX (proc_combo), ACTIVE_PROCESSES, _("Active processes"));
-
-	gtk_combo_box_set_active (GTK_COMBO_BOX (proc_combo), procdata->config.whose_process);
-
-	g_signal_connect (G_OBJECT (proc_combo), "changed",
-			  G_CALLBACK (cb_proc_combo_changed), procdata);
-
-  	label = gtk_label_new_with_mnemonic (_("Sho_w:"));
-  	gtk_label_set_mnemonic_widget (GTK_LABEL (label), proc_combo);
-	gtk_box_pack_end (GTK_BOX (hbox1), label, FALSE, FALSE, 0);
-
 	gtk_widget_show_all (hbox1);
 
 	scrolled = proctable_new (procdata);
@@ -179,17 +184,9 @@ create_proc_view (ProcData *procdata)
 	
 	hbox2 = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox2, FALSE, FALSE, 0);
-
-	infoview_create (procdata);
-	gtk_box_pack_start (GTK_BOX (hbox2), procdata->infoview.expander, FALSE, FALSE, 0);
-	gtk_expander_set_expanded (GTK_EXPANDER(procdata->infoview.expander),
-				   procdata->config.show_more_info);
-	gtk_widget_show (procdata->infoview.expander);
 	
-	vbox2 = gtk_vbox_new (FALSE, 0);
-	gtk_box_pack_end (GTK_BOX (hbox2), vbox2, FALSE, FALSE, 0);
 	procdata->endprocessbutton = gtk_button_new_with_mnemonic (_("End _Process"));
-	gtk_box_pack_end (GTK_BOX (vbox2), procdata->endprocessbutton, FALSE, FALSE, 0);
+	gtk_box_pack_end (GTK_BOX (hbox2), procdata->endprocessbutton, FALSE, FALSE, 0);
 	g_signal_connect (G_OBJECT (procdata->endprocessbutton), "clicked",
 			  G_CALLBACK (cb_end_process_button_pressed), procdata);
 	
@@ -201,32 +198,6 @@ create_proc_view (ProcData *procdata)
         return vbox1;
 }
 
-static int
-sort_bytes (GtkTreeModel *model, GtkTreeIter *itera, GtkTreeIter *iterb, gpointer data)
-{
-	int col = GPOINTER_TO_INT (data);
-	float btotal1, btotal2, bfree1, bfree2;
-
-	btotal1 = btotal2 = bfree1 = bfree2 = 0.0f;
-	gtk_tree_model_get (model, itera, 8, &btotal1, 9, &bfree1, -1);
-	gtk_tree_model_get (model, iterb, 8, &btotal2, 9, &bfree2, -1);
-
-	switch (col)
-	{
-		case 4:
-			return PROCMAN_CMP(btotal1, btotal2);
-
-		case 5:
-			return PROCMAN_CMP(bfree1, bfree2);
-
-		case 6:
-			return PROCMAN_CMP(btotal1 - bfree1, btotal2 - bfree2);
-
-		default:
-			g_assert_not_reached();
-			return 0;
-	}
-}
 
 GtkWidget *
 make_title_label (const char *text)
@@ -252,165 +223,34 @@ cpu_size_request (GtkWidget *box, GtkRequisition *req, ProcData *procdata)
 		MAX(req->width, procdata->cpu_label_fixed_width);
 }
 
-
-
-
-static GtkWidget*
-create_disk_view (ProcData *procdata)
+static void
+net_size_request (GtkWidget *label, GtkRequisition *req, ProcData *procdata)
 {
-	GtkWidget *disk_box, *disk_hbox;
-	GtkWidget *label, *spacer;
-	GtkWidget *scrolled;
-	GtkWidget *disk_tree;
-	GtkTreeStore *model;
-	GtkTreeViewColumn *col;
-	GtkCellRenderer *cell;
-	gint i;
-
-	static const gchar *titles[] = {
-	  N_("Device"),
-	  N_("Directory"),
-	  N_("Type"),
-	  N_("Total"),
-	  N_("Free"),
-	  N_("Used"),
-	};
-
-	PROCMAN_GETTEXT_ARRAY_INIT(titles);
-
-	disk_box = gtk_vbox_new (FALSE, 6);
-
-	gtk_container_set_border_width (GTK_CONTAINER (disk_box), 6);
-
-	label = make_title_label (_("Devices"));
-	gtk_box_pack_start (GTK_BOX (disk_box), label, FALSE, FALSE, 0);
-
-	disk_hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (disk_box), disk_hbox, TRUE, TRUE, 0);
-
-	spacer = gtk_label_new ("    ");
-	gtk_box_pack_start (GTK_BOX (disk_hbox), spacer, FALSE, FALSE, 0);
-
-	scrolled = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled), 
-					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
-                                             GTK_SHADOW_IN);
-
-	gtk_box_pack_start (GTK_BOX (disk_hbox), scrolled, TRUE, TRUE, 0);
-
-
-	model = gtk_tree_store_new (10,
-				    GDK_TYPE_PIXBUF,
-				    G_TYPE_STRING, /* device name */
-				    G_TYPE_STRING, /* directory */
-				    G_TYPE_STRING, /* type */
-				    G_TYPE_STRING, /* total */
-				    G_TYPE_STRING, /* free */
-				    G_TYPE_STRING, /* used */
-				    G_TYPE_FLOAT,
-				    G_TYPE_FLOAT,
-				    G_TYPE_FLOAT);
-
-	disk_tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
-	procdata->disk_list = disk_tree;
-	gtk_container_add (GTK_CONTAINER (scrolled), disk_tree);
-  	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (disk_tree), TRUE);
-  	g_object_unref (G_OBJECT (model));
-  	
- 	col = gtk_tree_view_column_new ();
-  	cell = gtk_cell_renderer_pixbuf_new ();
-	gtk_tree_view_column_pack_start (col, cell, FALSE);
-	gtk_tree_view_column_set_attributes (col, cell,
-					     "pixbuf", 0,
-					     NULL);
-		
-	cell = gtk_cell_renderer_text_new ();
-	gtk_tree_view_column_pack_start (col, cell, FALSE);
-	gtk_tree_view_column_set_attributes (col, cell,
-					     "text", 1,
-					     NULL);
-	gtk_tree_view_column_set_title (col, titles[0]);
-	gtk_tree_view_column_set_sort_column_id (col, 1);
-	gtk_tree_view_column_set_resizable (col, TRUE);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (disk_tree), col);
-								
-  	for (i = 1; i < 5	; i++) {
-  		cell = gtk_cell_renderer_text_new ();
-  		col = gtk_tree_view_column_new_with_attributes (titles[i],
-						    		cell,
-						     		"text", i + 1,
-						     		NULL);
-		gtk_tree_view_column_set_resizable (col, TRUE);
-		gtk_tree_view_column_set_sort_column_id (col, i + 1);
-		gtk_tree_view_append_column (GTK_TREE_VIEW (disk_tree), col);
-	}
-	
-	col = gtk_tree_view_column_new ();	
-
-	cell = gtk_cell_renderer_text_new ();
-	gtk_tree_view_column_pack_start (col, cell, FALSE);
-	gtk_tree_view_column_set_attributes (col, cell,
-					     "text", 6,
-					     NULL);
-	gtk_tree_view_column_set_title (col, titles[5]);
-		
-	
-	cell = gtk_cell_renderer_progress_new ();
-	gtk_tree_view_column_pack_start (col, cell, TRUE);
-	gtk_tree_view_column_set_attributes (col, cell,
-					     "value", 7,
-					     NULL);
-	
-	gtk_tree_view_append_column (GTK_TREE_VIEW (disk_tree), col);
-	gtk_tree_view_column_set_resizable (col, TRUE);
-	gtk_tree_view_column_set_sort_column_id (col, 6);
-	
-	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
-					 4, sort_bytes, GINT_TO_POINTER (4), NULL);
-	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
-					 5, sort_bytes, GINT_TO_POINTER (5), NULL);
-	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
-					 6, sort_bytes, GINT_TO_POINTER (6), NULL);
-
-
-	gtk_widget_show_all (disk_box);
-  	
-  	procman_get_tree_state (procdata->client, disk_tree, "/apps/procman/disktreenew");
-  	
-  	cb_update_disks (procdata);
-  	procdata->disk_timeout = gtk_timeout_add (procdata->config.disks_update_interval,
-  						  cb_update_disks, procdata);
-
-
-	return disk_box;
+	req->width = procdata->net_label_fixed_width = \
+		MAX(req->width, procdata->net_label_fixed_width);
 }
 
 
 
 
-
-
-
 static GtkWidget *
 create_sys_view (ProcData *procdata)
 {
 	GtkWidget *vbox, *hbox;
-	GtkWidget *cpu_box, *mem_box;
-	GtkWidget *cpu_hbox, *mem_hbox;
-	GtkWidget *cpu_graph_box, *mem_graph_box;
+	GtkWidget *cpu_box, *mem_box, *net_box;
+	GtkWidget *cpu_hbox, *mem_hbox, *net_hbox;
+	GtkWidget *cpu_graph_box, *mem_graph_box, *net_graph_box;
 	GtkWidget *label,*cpu_label, *spacer;
 	GtkWidget *table;
 	GtkWidget *color_picker;
 	GtkSizeGroup *sizegroup;
-	GdkColor color;
-	LoadGraph *cpu_graph, *mem_graph;
+	LoadGraph *cpu_graph, *mem_graph, *net_graph;
 	gint i;
 
 
 	vbox = gtk_vbox_new (FALSE, 18);
 
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
 
 	/* The CPU BOX */
 
@@ -431,7 +271,11 @@ create_sys_view (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (cpu_hbox), cpu_graph_box, TRUE, TRUE, 0);
 
 	cpu_graph = load_graph_new (LOAD_GRAPH_CPU, procdata);
-	gtk_box_pack_start (GTK_BOX (cpu_graph_box), cpu_graph->main_widget, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (cpu_graph_box),
+			    load_graph_get_widget(cpu_graph),
+			    TRUE,
+			    TRUE,
+			    0);
 
 	sizegroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
@@ -448,10 +292,8 @@ create_sys_view (ProcData *procdata)
 		g_signal_connect (G_OBJECT (temp_hbox), "size_request",
 					 G_CALLBACK (cpu_size_request), procdata);
 
-		color.red   = cpu_graph->colors[2+i].red;
-		color.green = cpu_graph->colors[2+i].green;
-		color.blue  = cpu_graph->colors[2+i].blue;
-		color_picker = gtk_color_button_new_with_color (&color);
+		color_picker = gtk_color_button_new_with_color (
+			&load_graph_get_colors(cpu_graph)[2+i]);
 
 		g_signal_connect (G_OBJECT (color_picker), "color_set",
 			    G_CALLBACK (cb_cpu_color_changed), GINT_TO_POINTER (i));
@@ -464,12 +306,12 @@ create_sys_view (ProcData *procdata)
 			text = g_strdup_printf (_("CPU%d:"), i+1);
 		}
 		label = gtk_label_new (text);
-		gtk_box_pack_start (GTK_BOX (temp_hbox), label, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (temp_hbox), label, FALSE, FALSE, 6);
 		g_free (text);
 		
 		cpu_label = gtk_label_new (NULL);
 		gtk_box_pack_start (GTK_BOX (temp_hbox), cpu_label, FALSE, FALSE, 0);
-		cpu_graph->cpu_labels[i] = cpu_label;
+		load_graph_get_labels(cpu_graph)->cpu[i] = cpu_label;
 		
 	}
 	
@@ -496,8 +338,11 @@ create_sys_view (ProcData *procdata)
 
 
 	mem_graph = load_graph_new (LOAD_GRAPH_MEM, procdata);
-	gtk_box_pack_start (GTK_BOX (mem_graph_box), mem_graph->main_widget, 
-			    TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (mem_graph_box),
+			    load_graph_get_widget(mem_graph),
+			    TRUE,
+			    TRUE,
+			    0);
 	
 	table = gtk_table_new (2, 7, FALSE);
 	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
@@ -505,11 +350,8 @@ create_sys_view (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (mem_graph_box), table, 
 			    FALSE, FALSE, 0);
 
-
-	color.red   = mem_graph->colors[2].red;
-	color.green = mem_graph->colors[2].green;
-	color.blue  = mem_graph->colors[2].blue;
-	color_picker = gtk_color_button_new_with_color (&color);
+	color_picker = gtk_color_button_new_with_color (
+		&load_graph_get_colors(mem_graph)[2]);
 	g_signal_connect (G_OBJECT (color_picker), "color_set",
 			    G_CALLBACK (cb_mem_color_changed), procdata);
 	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 0, 1, 0, 0, 0, 0);
@@ -518,29 +360,57 @@ create_sys_view (ProcData *procdata)
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
 	
-	mem_graph->memused_label = gtk_label_new ("");
-	gtk_misc_set_alignment (GTK_MISC (mem_graph->memused_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->memused_label, 2, 3, 0, 1, 
-			  GTK_FILL, 0, 0, 0);
+	gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(mem_graph)->memused),
+				0.0,
+				0.5);
+	gtk_table_attach (GTK_TABLE (table),
+			  load_graph_get_labels(mem_graph)->memused,
+			  2,
+			  3,
+			  0,
+			  1,
+			  GTK_FILL,
+			  0,
+			  0,
+			  0);
 	
 	label = gtk_label_new (_("of"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 3, 4, 0, 1, GTK_FILL, 0, 0, 0);
 	
-	mem_graph->memtotal_label = gtk_label_new ("");
-	gtk_misc_set_alignment (GTK_MISC (mem_graph->memtotal_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->memtotal_label, 4, 5, 0, 1, 
-			  GTK_FILL, 0, 0, 0);
+
+	gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(mem_graph)->memtotal),
+				0.0,
+				0.5);
+
+	gtk_table_attach (GTK_TABLE (table),
+			  load_graph_get_labels(mem_graph)->memtotal,
+			  4,
+			  5,
+			  0,
+			  1,
+			  GTK_FILL,
+			  0,
+			  0,
+			  0);
 	
-	mem_graph->mempercent_label = gtk_label_new ("");
-	gtk_misc_set_alignment (GTK_MISC (mem_graph->mempercent_label), 1.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->mempercent_label, 5, 6, 0, 1, 
-			  GTK_FILL, 0, 0, 0);
-			  
-	color.red   = mem_graph->colors[3].red;
-	color.green = mem_graph->colors[3].green;
-	color.blue  = mem_graph->colors[3].blue;
-	color_picker = gtk_color_button_new_with_color (&color);
+
+	gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(mem_graph)->mempercent),
+					  1.0,
+					  0.5);
+	gtk_table_attach (GTK_TABLE (table),
+			  load_graph_get_labels(mem_graph)->mempercent,
+			  5,
+			  6,
+			  0,
+			  1,
+			  GTK_FILL,
+			  0,
+			  0,
+			  0);
+
+	color_picker = gtk_color_button_new_with_color (
+		&load_graph_get_colors(mem_graph)[3]);
 	g_signal_connect (G_OBJECT (color_picker), "color_set",
 			    G_CALLBACK (cb_swap_color_changed), procdata);
 	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 1, 2, 0, 0, 0, 0);
@@ -549,26 +419,177 @@ create_sys_view (ProcData *procdata)
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
 	
-	mem_graph->swapused_label = gtk_label_new ("");
-	gtk_misc_set_alignment (GTK_MISC (mem_graph->swapused_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->swapused_label, 2, 3, 1, 2, 
-			  GTK_FILL, 0, 0, 0);
+
+	gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(mem_graph)->swapused ),
+				0.0,
+				0.5);
+	gtk_table_attach (GTK_TABLE (table),
+			  load_graph_get_labels(mem_graph)->swapused,
+			  2,
+			  3,
+			  1,
+			  2,
+			  GTK_FILL,
+			  0,
+			  0,
+			  0);
 			  
 	label = gtk_label_new (_("of"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 3, 4, 1, 2, GTK_FILL, 0, 0, 0);
 	
-	mem_graph->swaptotal_label = gtk_label_new ("");
-	gtk_misc_set_alignment (GTK_MISC (mem_graph->swaptotal_label), 0.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->swaptotal_label, 4, 5, 1, 2, 
-			  GTK_FILL, 0, 0, 0);	
-	
-	mem_graph->swappercent_label = gtk_label_new ("");
-	gtk_misc_set_alignment (GTK_MISC (mem_graph->swappercent_label), 1.0, 0.5);
-	gtk_table_attach (GTK_TABLE (table), mem_graph->swappercent_label, 5, 6, 1, 2, 
-			  GTK_FILL, 0, 0, 0);
-			  
+
+	gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(mem_graph)->swaptotal),
+				0.0,
+				0.5);
+	gtk_table_attach (GTK_TABLE (table),
+			  load_graph_get_labels(mem_graph)->swaptotal,
+			  4,
+			  5,
+			  1,
+			  2,
+			  GTK_FILL,
+			  0,
+			  0,
+			  0);
+
+
+	gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(mem_graph)->swappercent),
+				1.0,
+				0.5);
+	gtk_table_attach (GTK_TABLE (table),
+			  load_graph_get_labels(mem_graph)->swappercent,
+			  5,
+			  6,
+			  1,
+			  2,
+			  GTK_FILL,
+			  0,
+			  0,
+			  0);
+
 	procdata->mem_graph = mem_graph;
+
+	/* The net box */
+	net_box = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (vbox), net_box, TRUE, TRUE, 0);
+
+	label = make_title_label (_("Network History"));
+	gtk_widget_show (label);
+	gtk_box_pack_start (GTK_BOX (net_box), label, FALSE, FALSE, 0);
+
+	net_hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (net_box), net_hbox, TRUE, TRUE, 0);
+
+	spacer = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (net_hbox), spacer, FALSE, FALSE, 0);
+
+	net_graph_box = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (net_hbox), net_graph_box, TRUE, TRUE, 0);
+
+	net_graph = load_graph_new (LOAD_GRAPH_NET, procdata);
+	gtk_box_pack_start (GTK_BOX (net_graph_box),
+			    load_graph_get_widget(net_graph),
+			    TRUE,
+			    TRUE,
+			    0);
+
+	table = gtk_table_new (2, 5, FALSE);
+	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
+	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
+	gtk_box_pack_start (GTK_BOX (net_graph_box), table,
+			    FALSE, FALSE, 0);
+
+	color_picker = gtk_color_button_new_with_color (
+		&load_graph_get_colors(net_graph)[2]);
+	g_signal_connect (G_OBJECT (color_picker), "color_set",
+			    G_CALLBACK (cb_net_in_color_changed), procdata);
+	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 0, 1, 0, 0, 0, 0);
+
+	label = gtk_label_new (_("Received:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
+
+	hbox = gtk_hbox_new (FALSE, 0);
+	g_signal_connect (G_OBJECT (hbox), "size_request",
+			  G_CALLBACK (net_size_request), procdata);
+
+
+	gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(net_graph)->net_in),
+				0.0,
+				0.5);
+	gtk_box_pack_start (GTK_BOX (hbox),
+			    load_graph_get_labels(net_graph)->net_in,
+			    FALSE,
+			    FALSE,
+			    0);
+
+	gtk_table_attach (GTK_TABLE (table), hbox, 2, 3, 0, 1, GTK_FILL, 0, 0, 0);
+
+	label = gtk_label_new (_("Total:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 3, 4, 0, 1, GTK_FILL, 0, 0, 0);
+
+	gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(net_graph)->net_in_total),
+				0.0,
+				0.5);
+	gtk_table_attach (GTK_TABLE (table),
+			  load_graph_get_labels(net_graph)->net_in_total,
+			  4,
+			  5,
+			  0,
+			  1,
+			  GTK_FILL,
+			  0,
+			  0,
+			  0);
+
+	color_picker = gtk_color_button_new_with_color (
+		&load_graph_get_colors(net_graph)[3]);
+	g_signal_connect (G_OBJECT (color_picker), "color_set",
+			    G_CALLBACK (cb_net_out_color_changed), procdata);
+	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 1, 2, 0, 0, 0, 0);
+
+	label = gtk_label_new (_("Sent:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
+
+	hbox = gtk_hbox_new (FALSE, 0);
+	g_signal_connect (G_OBJECT (hbox), "size_request",
+			  G_CALLBACK (net_size_request), procdata);
+
+	gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(net_graph)->net_out),
+				0.0,
+				0.5);
+	gtk_box_pack_start (GTK_BOX (hbox),
+			    load_graph_get_labels(net_graph)->net_out,
+			    FALSE,
+			    FALSE,
+			    0);
+
+	gtk_table_attach (GTK_TABLE (table), hbox, 2, 3, 1, 2, GTK_FILL, 0, 0, 0);
+
+	label = gtk_label_new (_("Total:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), label, 3, 4, 1, 2, GTK_FILL, 0, 0, 0);
+
+	gtk_misc_set_alignment (GTK_MISC (load_graph_get_labels(net_graph)->net_out_total),
+				0.0,
+				0.5);
+	gtk_table_attach (GTK_TABLE (table),
+			  load_graph_get_labels(net_graph)->net_out_total,
+			  4,
+			  5,
+			  1,
+			  2,
+			  GTK_FILL,
+			  0,
+			  0,
+			  0);
+
+	procdata->net_graph = net_graph;
+
+
 	gtk_widget_show_all (vbox);
 
 	return vbox;
@@ -582,7 +603,7 @@ menu_item_select_cb (GtkMenuItem *proxy,
 	char *message;
 
 	action = g_object_get_data (G_OBJECT (proxy),  "gtk-action");
-	g_return_if_fail (action != NULL);
+	g_assert(action);
 
 	g_object_get (G_OBJECT (action), "tooltip", &message, NULL);
 	if (message)
@@ -683,6 +704,13 @@ create_main_window (ProcData *procdata)
 	                                     G_N_ELEMENTS (toggle_menu_entries),
 	                                     procdata);
 
+	gtk_action_group_add_radio_actions (procdata->action_group,
+					    radio_menu_entries,
+					    G_N_ELEMENTS (radio_menu_entries),
+					    procdata->config.whose_process,
+					    G_CALLBACK(cb_radio_processes),
+					    procdata);
+
 	gtk_ui_manager_insert_action_group (procdata->uimanager,
 	                                    procdata->action_group,
 	                                    0);
@@ -741,11 +769,6 @@ create_main_window (ProcData *procdata)
 	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
 				      procdata->config.show_tree);
 
-	action = gtk_action_group_get_action (procdata->action_group, "ShowThreads");
-	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
-				      procdata->config.show_threads);
-
-
 	procdata->app = app;
 }
 
@@ -779,7 +802,10 @@ update_sensitivity (ProcData *data, gboolean sensitivity)
 		gtk_widget_set_sensitive (data->endprocessbutton, sensitivity);
 	}
 
-	gtk_widget_set_sensitive (data->infoview.box, sensitivity);
+	action = gtk_action_group_get_action (data->action_group, "StopProcess");
+	gtk_action_set_sensitive (action, sensitivity);
+	action = gtk_action_group_get_action (data->action_group, "ContProcess");
+	gtk_action_set_sensitive (action, sensitivity);
 
 	action = gtk_action_group_get_action (data->action_group, "EndProcess");
 	gtk_action_set_sensitive (action, sensitivity);
@@ -810,17 +836,3 @@ cb_toggle_tree (GtkAction *action, gpointer data)
 
 	gconf_client_set_bool (client, "/apps/procman/show_tree", show, NULL);
 }
-
-static void		
-cb_toggle_threads (GtkAction *action, gpointer data)
-{
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	gboolean show;
-
-	show = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	if (show == procdata->config.show_threads)
-		return;
-
-	gconf_client_set_bool (client, "/apps/procman/show_threads", show, NULL);
-}
