@@ -103,3 +103,55 @@ SI_gnome_vfs_format_file_size_for_display (GnomeVFSFileSize size)
 		}
 	}
 }
+
+
+
+gboolean
+load_symbols(const char *module, ...)
+{
+	GModule *mod;
+	gboolean found_all = TRUE;
+	va_list args;
+
+	mod = g_module_open(module, G_MODULE_BIND_LAZY | G_MODULE_BIND_LOCAL);
+
+	if (!mod)
+		return FALSE;
+
+	g_print("Found %s\n", module);
+
+	va_start(args, module);
+
+	while (1) {
+		const char *name;
+		void **symbol;
+
+		name = va_arg(args, char*);
+
+		if (!name)
+			break;
+
+		symbol = va_arg(args, void**);
+
+		if (g_module_symbol(mod, name, symbol)) {
+			g_print("Loaded %s from %s\n", name, module);
+		}
+		else {
+			g_print("Could not load %s from %s\n", name, module);
+			found_all = FALSE;
+			break;
+		}
+	}
+
+	va_end(args);
+
+
+	if (found_all)
+		g_module_make_resident(mod);
+	else
+		g_module_close(mod);
+
+	return found_all;
+}
+
+
